package com.qmth.themis.exam.websocketTemplete;

import com.alibaba.fastjson.JSONObject;
import com.qmth.themis.business.cache.ExamRecordCacheUtil;
import com.qmth.themis.business.constant.SystemConstant;
import com.qmth.themis.business.dto.WebsocketDto;
import com.qmth.themis.business.enums.ExamRecordStatusEnum;
import com.qmth.themis.business.enums.WebsocketTypeEnum;
import com.qmth.themis.common.enums.ExceptionResultEnum;
import com.qmth.themis.common.exception.BusinessException;
import com.qmth.themis.exam.config.ExamConstant;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.Objects;

/**
 * @Description: 考生端mobile websocket模版
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2020/7/24
 */
@Component
public class WebSocketMobileMessageTemplete {
    private final static Logger log = LoggerFactory.getLogger(WebSocketMobileMessageTemplete.class);

    /**
     * 状态同步
     *
     * @param body
     * @return
     */
    public WebsocketDto syncStatus(String body) {
        JSONObject jsonObject = JSONObject.parseObject(body);
        log.info("syncStatus jsonObject:{}", jsonObject.toJSONString());
        if (Objects.isNull(jsonObject.get("recordId")) || Objects.equals(jsonObject.get("recordId"), "")) {
            throw new BusinessException(ExceptionResultEnum.RECORD_ID_IS_NULL);
        }
        Long recordId = Long.parseLong(String.valueOf(jsonObject.get("recordId")));
        ExamRecordStatusEnum status = ExamRecordCacheUtil.getStatus(recordId);
        if (Objects.nonNull(status) && Objects.equals(ExamRecordStatusEnum.BREAK_OFF, status)) {//如果是已中断状态，则给客户端和移动端发送考试停止的消息
            ExamConstant.sendExamStopMsg(recordId);
        }
        return this.syncAck(body);
    }

    /**
     * 同步确认
     *
     * @param body
     * @return
     */
    public WebsocketDto syncAck(String body) {
        return new WebsocketDto(WebsocketTypeEnum.convertToName(Thread.currentThread().getStackTrace()[1].getMethodName()), Collections.singletonMap(SystemConstant.ACK_MESSAGE, System.currentTimeMillis()));
    }
}
